#
# spec file for package emacs-w3m
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           emacs-w3m
Summary:        An interface program to use w3m with Emacs
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Browsers
# Summary(ja): w3m を Emacs 上で動かすためのプログラムです
Version:        1.4.632+546+gf8819bca
Release:        1.1
URL:            http://emacs-w3m.namazu.org/
Source0:        emacs-w3m-%{version}.tar.xz
Source1:        suse-start.el
Patch1:         w3m-el-1.3-map.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
BuildRequires:  autoconf
BuildRequires:  emacs-nox
BuildRequires:  flim
BuildRequires:  makeinfo
Requires:       apel
Requires:       emacs
Requires:       flim
Requires:       w3m
Provides:       w3m-el = %{version}
Obsoletes:      w3m-el < %{version}
# %description -l ja
# Emacs 上で動作するブラウザと言えば，普通 W3 のことですが，動作が非常に
# 遅いので，なかなか常用しようという気になれません．
#
# それに対して，w3m というテキストベースで動作するブラウザがあり，非常に
# 軽快に動作するので重宝しているのですが，端末に移動しなければいけないの
# が面倒です．
#
# そこで，w3m を HTML の rendering engine として使用し，表示とインタフェー
# スのみをEmacs で動かすようにすればいいんじゃないだろうか，ということを
# 考えました．

%description
Emacs-w3m is an interface program to use w3m with Emacs.

W3 is the most well known WEB browser which works on (X)Emacs, but it
is very slow. Emacs-w3m is an alternative. It uses w3m, which is a pager
with WWW capability, developed by Akinori ITO. It is a pager, but it
can be used as a text-mode WWW browser.

%prep
%setup -q
%patch1

%build
%define emacs_sitelisp_dir %{_datadir}/emacs/site-lisp
%define emacs_package_dir %{emacs_sitelisp_dir}/w3m
autoreconf --force --install
%configure \
            --with-lispdir=%{emacs_package_dir} \
            --with-icondir=%{emacs_package_dir} \
            --with-emacs=emacs
make

%install
mkdir -p %{buildroot}/%{emacs_package_dir}
%make_install install-icons
{
  echo ";; %{emacs_sitelisp_dir}/suse-start-%{name}.el"
  echo ""
  echo "(add-to-list 'load-path \"%{emacs_package_dir}\")"
  echo ""
  cat %{_sourcedir}/suse-start.el
  echo ""
  echo ";; %{emacs_sitelisp_dir}/suse-start-%{name}.el ends here"
} > %{buildroot}%{emacs_sitelisp_dir}/suse-start-%{name}.el
rm -f %{buildroot}/%{_infodir}/dir
rm -f %{buildroot}/%{emacs_package_dir}/ChangeLog*

%post
for i in emacs-w3m emacs-w3m-ja
do
    %install_info --info-dir=%{_infodir} %{_infodir}/${i}.info.gz
done

%preun
for i in emacs-w3m emacs-w3m-ja
do
    %install_info_delete --info-dir=%{_infodir} %{_infodir}/${i}.info.gz
done

%files
%defattr(-,root,root)
%license COPYING
%doc ChangeLog* README*
%{emacs_package_dir}
%config %{emacs_sitelisp_dir}/suse-start-%{name}.el
%{_infodir}/*

%changelog
* Sat Apr  1 2023 schwab@linux-m68k.org
- Update to version 1.4.632+546+gf8819bca:
  * Silence the byte-compiler on Emacs 30
  * ; sb-sankei.el (shimbun-sankei-login): Fix the way to parse forms
  * Silence the byte compiler
  * Silence warnings when compiling w3m.el individually ([emacs-w3m:13914])
  * ; Fix last change in aclocal.m4
  * Support Emacs 30
  * Update ChangeLog
  * Fix w3m-puny-encode1 failure on Emacs 29
  * * w3m.el (w3m-unsafe-url-warning): New face
* Sat Apr  9 2022 schwab@linux-m68k.org
- Update to version 1.4.632+512+gc3a3a947:
  * * Makefile.in (configure): Replace configure.in with configure.ac
  * Make the builder work for autoconf 2.70 and up as well
  * Drop Emacs 26 support
  * * shimbun/ChangeLog: Remove cancelled entry
  * * sb-kyoko-np.el (shimbun-clear-contents): Revert
  * * sb-kyoko-np.el (shimbun-clear-contents): Make date header precision
  * * mime-w3m.el: Fix last change
  * Typo fix
  * Conceal warnings for the case SEMI is absent (issue #108)
  * * sb-sankei.el (w3m-cookie-setup): Autoload it
  * * w3m.el (w3m-image-type-alist): Update docstring
* Fri Oct 15 2021 schwab@linux-m68k.org
- Update to version 1.4.632+501+gc088fe62:
  * * w3m-lnum.el (w3m-lnum-get-match-info, w3m-lnum-get-action): Rearrange docstrings so to be in 80-column
  * Typo fix
  * Use rfc6068.el if possible instead of rfc2368.el (issue #109)
  * * sb-sankei.el (shimbun-sankei-keep-login): Consult akamai cookie instead of local timer for expiry period. (shimbun-sankei-logout): Remove login/out cookies first and save last. (shimbun-sankei-login): Remove akamai cookie first as well. (shimbun-sankei-last-login): Remove variable. (shimbun-sankei-get-headers): Use date-to-time instead of encode-time and parse-time-string or timezone-parse-date.
  * * w3m-filter.el (w3m-filter-configuration): Add desc template
  * * w3m-filter.el (w3m-filter-configuration): Make Custom-set work
  * * w3m-bookmark.el (w3m-bookmark-menubar-update): Add a workaround to avoid a miscellaneous error
  * Treat application/emacs-lisp as text/plain ([emacs-w3m:13845])
  * user-agents: bugfix, update, improve friendliness (PR#106)
  * * w3m.el (w3m-user-agent-alist): Fill in in 80-column, reindent
  * user-agent variables: update, and add reference feature
  * w3m-user-agent-default-alist: bugfix macro element
  * New and improved filter for github (PR#105)
  * * w3m-filter.el (w3m-filter-github): Fill in in 80-column, reindent
  * w3m-filter: new and improved filter for github
  * * sb-sankei.el (shimbun-headers): Run shimbun-sankei-keep-login
  * * sb-sankei.el (shimbun-sankei-login): Cache a copy of password always
  * * sb-sankei.el (shimbun-sankei-logout{in|out}): Make those functions, instead of shimbun-sankei-keep-login, manage shimbun-sankei-last-login.
  * * sb-sankei.el (shimbun-sankei-keep-login): Fix last commit
  * Keep logging in in Sankei
  * Add timeout to w3m-download
  * Fix last commit (1059e92)
  * Hard-code the shell used in `w3m-download' with "sh" ([emacs-w3m:13826])
  * Use defvar-local in w3m.el (PR#101)
  * Replace make-variable-buffer-local with defvar-local
  * Bugfix: db-history single-page advances point too far (PR#100)
  * * w3m.el (w3m--goto-url--handler-function): Fix point position. (PR#99)
  * Position point on the first entry in the db history (PR#99) ;; slightly modified by yamaoka
  * Fix typo 講読→購読
  * reindent
  * Bugfix: db-history single-page advances point too far
  * * w3m.el (w3m--goto-url--handler-function): Fix point position. (PR#99)
  * Position point on the first entry in the db history (PR#99) ;; slightly modified by yamaoka
  * Fix typo 講読→購読
  * reindent
  * Fix typo 講読→購読
  * Add docstring for function w3m--goto-url--handler-function
  * db-history: advance to first history link
  * reindent
  * force-wide-display
  * (shimbun-sankei-clear-contents): Show restrictions
  * Fix previous commit
  * Delete nonsense distinction of writer and byliner
  * (shimbun-sankei-clear-contents): Distinguish author and writer
  * Fix last commit
  * Fix last commit
  * Add iframe tag to movie tag so to be able to view it in other browsers
  * Add links to embedded movies on Sankei
  * * sb-sankei.el (shimbun-sankei-clear-contents): Fix regexp
  * * sb-sankei.el (shimbun-sankei-clear-contents): Fix regexp
  * Support multiple article pages on Sankei
  * Minor fix in last commit
  * Show author name if it is expressed clearly in the original
  * Minor improvements on read and scan-sexps usage
  * * sb-yoshirin.el: Spelling fix: thumnail -> thumbnail
  * Minor fix to Sankei
  * Display most detailed headline on Sankei
  * Display headline that might be the only place to show the author
  * Bugfix: make w3m-select-buffer-toggle-style work properly (PR#95)
  * Make Sankei support raw html embedded in java script
  * * sb-sankei.el (shimbun-sankei-clear-contents): Modify last commit
  * * sb-sankei.el (shimbun-sankei-clear-contents): Don't infloop
  * * sb-sankei.el (shimbun-sankei-clear-contents) : Fix regexps
  * * sb-sankei.el (shimbun-sankei-clear-contents) : Trivial fix
  * Make Sankei work on Emacs 26 and 27
  * Make Sankei support raw html embedded in java script
  * * sb-sankei.el (shimbun-sankei-clear-contents): Modify last commit
  * * sb-sankei.el (shimbun-sankei-clear-contents): Don't infloop
  * * sb-sankei.el (shimbun-sankei-clear-contents) : Fix regexps
  * * sb-sankei.el (shimbun-sankei-clear-contents) : Trivial fix
  * Make Sankei work on Emacs 26 and 27
  * Sigh; w3m-select-buffer-window needs to match the selected w3m buffer, not the select buffer.
  * Ensure that w3m-select-buffer-window is kept updated properly.
  * By the time split-window is called, the locally let selected-window variable is no longer a valid window. Thus, we *actually* need to call the selected-window function here.
  * Fetch more images
  * * doc/emacs-w3m.texi, doc/emacs-w3m-ja.texi (Newspapers Supported by Shimbun): Update Sankei groups.
  * Make Sankei work
  * Make Mainichi work
  * Make Asahi work (as for at least the rss group)
  * Declare w3m-queries-log-file in w3m-util.el
  * Move w3m-queries-log-file from w3m-util.el to w3m.el
  * Update
  * Reindent
  * w3m-queries-log-file: Use expand-file-name in variable defcustom
  * tweaks to handling url query parts
  * Update
  * Reindent
  * Place entire logic in function w3m-external-view
  * Revert last change that made `w3m-process-stop' do kill page buffer
  * Reindent
  * w3m-delete-buffer-if-empty: Only operate on live buffers
  * Fixes for w3m-current-url = NIL, loading images from ext program
  * Delete useless history warning
  * Make shimbun-sankei-login work
  * Silence the byte compiler on Emacs 28
* Sun Mar 21 2021 schwab@linux-m68k.org
- Update to version 1.4.632+396+g051dba16:
  * Don't show a backstage while performing `text-scale-adjust'
  * Make text-scale-adjust work
  * Fix it again
  * shimbun.el (shimbun-xml-parse-buffer): Fix typo
  * ChangeLog: fix date entries
  * * shimbun.el (shimbun-xml-parse-buffer): Work around malformed xml
  * Update copyright years
  * Docfix so not to be wider than 80 chars
  * Bugfix 'w3m-previous-image doesn't work' ([emacs-w3m:13747])
  * Fix typo in ChangeLog
* Tue Feb 25 2020 Andreas Schwab <schwab@linux-m68k.org>
- Update to current GIT HEAD (6eda3828)
* Sat Jul 14 2018 jengelh@inai.de
- Trim bias from description.
- Replace old RPM shell vars by macros.
* Sun Jul  8 2018 schwab@linux-m68k.org
- Rename from w3m-el to emacs-w3m
- Update to current CVS head (version 1.4.631)
  * Work for Emacs >= 26 in which the emacs-version variable no longer
    includes the build number
  * Refactor w3m-process-queue memory and redability
  * Make progress messages more uniform and more useful
  * Work for mailto urls
  * Update faces for all navigation cases
  * Fix two bugs in navigating the w3m-session-select popup window
  * Bugfix for the creation of session pop-up window
  * Uniform error handling and message presentation
  * Introduce w3m-display-mode
  * Send a cached ETag to the remote server so as to check whether
    the server responds with 304 meaning the cache is still up-to-date
  * Delete about://cookie/ buffer when w3m-view-previous-page is performed
  * Update selection buffer properly after deletion or renaming
  * Fix cookies handling
- Use %%license for COPYING
- Remove xemacs subpackage, not compatible with xemacs any more
* Fri Dec  9 2016 schwab@linux-m68k.org
- Update to current CVS head (version 1.4.567)
  * make it work with emacs 26
* Mon Dec 17 2012 tiwai@suse.de
- Remove the invalid leading URL from Source to make
  source_validator happy
- Remove obsolete flavour.patch
* Tue Dec  4 2012 schwab@linux-m68k.org
- Update to current CVS head
- Use w3m-load in suse-start.el
- Modernize specfile
- Reduce build requires
* Mon Jul 16 2012 tiwai@suse.de
- Drop mule-ucs-xemacs dependency, too (bnc#771421)
* Mon Jul 16 2012 tiwai@suse.de
- Drop Mule-UCS dependency on openSUSE-12.2 (bnc#771421)
* Mon Jul  2 2012 werner@suse.de
- Make it build with emacs 24.1
* Tue Nov 15 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Jan 24 2008 mfabian@suse.de
- proper fix for the problem in the last comment is now included
  from upstream CVS.
* Tue Jan  8 2008 mfabian@suse.de
-  add workaround for missing function on XEmacs
  unencodable-char-position-does-not-exist-in-xemacs.patch
  Patch taken from:
  http://news.gmane.org/find-root.php?message_id=%%3cb4mr6gu1h47.fsf%%40jpl.org%%3e
* Tue Jan  8 2008 mfabian@suse.de
- update to 1.4.4.20080108 (CVS HEAD).
  • Do not kill process when the buffer associated to it is alive
* Tue Dec  4 2007 mfabian@suse.de
- remove openldap2 from BuildRequires.
* Wed Jul 18 2007 mfabian@suse.de
- update to 1.4.4.20070717 (CVS HEAD). Fixes the problem that
  buttons in forms didn't work anymore, see
  http://emacs-w3m.namazu.org/ml/msg09431.html
* Tue Jul 17 2007 mfabian@suse.de
- update to 1.4.4.20070704 (CVS HEAD).
* Mon Mar 26 2007 mfabian@suse.de
- update to 1.4.4.20070326 (CVS HEAD).
- remove old patches w3m-el-1.3.1-expires-time.patch and
  w3m-el-1.4.3-obsolete.patch.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri May  6 2005 schwab@suse.de
- Don't use obsolete functions.
* Sun Aug 29 2004 schwab@suse.de
- Update to emacs-w3m 1.4.3.
* Sun Jun 27 2004 schwab@suse.de
- Don't set w3m-mailto-url-function to compose-mail, it can't handle URLs.
* Tue Feb  3 2004 hmacht@suse.de
- added option # norootforbuild in specfile
* Fri Aug 22 2003 mfabian@suse.de
- add xemacs-packagages and xemacs-packages-info to
  "# neededforbuild".
* Tue Aug 12 2003 mfabian@suse.de
- w3m-el-xemacs needs its own %%post and %%preun for install-info.
- don't just remove the %%{buildroot} from the comments in the .elc
  files, replace it with an equal amount of spaces in order not
  to change the offsets used for the docstrings.
* Tue Aug 12 2003 mfabian@suse.de
- update to 1.3.6
- remove %%{buildroot} from comments in .elc files to make it
  pass the build checks.
- add info files.
* Fri Jun 13 2003 mfabian@suse.de
- fix "directory not owned by any package".
* Thu Mar  6 2003 ro@suse.de
- removed cyrus-sasl from neededforbuild
* Tue Jan 14 2003 mfabian@suse.de
- update to 1.3.3
- disable obsolete w3m-el-1.2.6-select.patch
* Wed Nov 13 2002 ro@suse.de
- use x-devel-packages in neededforbuild
* Mon Aug 19 2002 mfabian@suse.de
- add (setq w3m-use-cookies t) to suse-start-w3m-el.el
* Sat Aug 17 2002 mfabian@suse.de
- fix parsing of cookie "expires" time string.
* Mon Aug 12 2002 mfabian@suse.de
- Update to version 1.3.1
- rm config.cache before configuring for XEmacs.
* Mon Aug 12 2002 ro@suse.de
- added canna-libs to neededforbuild
* Sun Jul  7 2002 schwab@suse.de
- Update to version 1.3.
* Tue Jun  4 2002 schwab@suse.de
- Fix requires.
* Thu Mar 21 2002 schwab@suse.de
- Update to version 1.2.6.
- Fix redisplay of checkboxes.
- Improve handling of <SELECT MULTIPLE>.
* Wed Mar 20 2002 mfabian@suse.de
- fix w3m-el-1.2.1-select.patch for XEmacs
  (in XEmacs, 'replace-regexp-in-string' is called
  'replace-in-string' and has a different order of parameters)
* Tue Mar 19 2002 schwab@suse.de
- Normalize whitespace and decode entities in <OPTION> text.
* Mon Mar 11 2002 schwab@suse.de
- Fix entities inside <AREA>.
* Tue Mar  5 2002 schwab@suse.de
- Fix handling of <SELECT MULTIPLE>.
* Tue Feb 12 2002 mfabian@suse.de
- merge w3m-el.spec and w3m-el-xemacs.spec (save a bit space
  in the source rpms)
- remove bogus suse-start.{el,elc}
* Tue Feb 12 2002 schwab@suse.de
- Fix entities inside <textarea>.
* Fri Feb  1 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Sun Jan 27 2002 mfabian@suse.de
- update to version 1.2.4
* Thu Nov 29 2001 mfabian@suse.de
- new package: w3m-el, version 1.2.1
